@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2007 Henrique Pinto <henrique.pinto@kdemail.net>
  * Copyright (c) 2008-2009 Harald Hvaal <haraldhv@stud.ntnu.no>
- * Copyright (c) 2009 Raphael Kubo da Costa <kubito@gmail.com>
+ * Copyright (c) 2009-2010 Raphael Kubo da Costa <kubito@gmail.com>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -37,10 +37,11 @@
 
 namespace Kerfuffle
 {
+
 Job::Job(ReadOnlyArchiveInterface *interface, QObject *parent)
-        : KJob(parent)
-        , m_interface(interface)
-        , m_workerThread(0)
+    : KJob(parent)
+    , m_interface(interface)
+    , m_workerThread(0)
 {
     static bool onlyOnce = false;
     if (!onlyOnce) {
@@ -120,10 +121,10 @@ bool Job::doKill()
 }
 
 ListJob::ListJob(ReadOnlyArchiveInterface *interface, QObject *parent)
-        : Job(interface, parent),
-        m_isSingleFolderArchive(true),
-        m_isPasswordProtected(false),
-        m_extractedFilesSize(0)
+    : Job(interface, parent)
+    , m_isSingleFolderArchive(true)
+    , m_isPasswordProtected(false)
+    , m_extractedFilesSize(0)
 {
     connect(this, SIGNAL(newEntry(const ArchiveEntry&)),
             this, SLOT(onNewEntry(const ArchiveEntry&)));
@@ -140,17 +141,17 @@ void ListJob::doWork()
     }
 }
 
-qlonglong ListJob::extractedFilesSize()
+qlonglong ListJob::extractedFilesSize() const
 {
     return m_extractedFilesSize;
 }
 
-bool ListJob::isPasswordProtected()
+bool ListJob::isPasswordProtected() const
 {
     return m_isPasswordProtected;
 }
 
-bool ListJob::isSingleFolderArchive()
+bool ListJob::isSingleFolderArchive() const
 {
     return m_isSingleFolderArchive;
 }
@@ -176,14 +177,16 @@ void ListJob::onNewEntry(const ArchiveEntry& entry)
     }
 }
 
-QString ListJob::subfolderName()
+QString ListJob::subfolderName() const
 {
     return m_subfolderName;
 }
 
-ExtractJob::ExtractJob(const QList<QVariant>& files, const QString& destinationDir,
-                       ExtractionOptions options, ReadOnlyArchiveInterface *interface, QObject *parent)
-        : Job(interface,  parent), m_files(files), m_destinationDir(destinationDir), m_options(options)
+ExtractJob::ExtractJob(const QVariantList& files, const QString& destinationDir, ExtractionOptions options, ReadOnlyArchiveInterface *interface, QObject *parent)
+    : Job(interface, parent)
+    , m_files(files)
+    , m_destinationDir(destinationDir)
+    , m_options(options)
 {
 }
 
@@ -221,9 +224,10 @@ void ExtractJob::fillInDefaultValues(ExtractionOptions& options)
 }
 
 AddJob::AddJob(const QStringList& files, const CompressionOptions& options , ReadWriteArchiveInterface *interface, QObject *parent)
-        : Job(interface, parent), m_files(files), m_options(options)
+    : Job(interface, parent)
+    , m_files(files)
+    , m_options(options)
 {
-    kDebug();
 }
 
 void AddJob::doWork()
@@ -231,8 +235,7 @@ void AddJob::doWork()
     emit description(this, i18np("Adding a file", "Adding %1 files", m_files.count()));
 
     ReadWriteArchiveInterface *m_writeInterface =
-        qobject_cast<ReadWriteArchiveInterface*>
-        (m_interface);
+        qobject_cast<ReadWriteArchiveInterface*>(m_interface);
 
     Q_ASSERT(m_writeInterface);
 
@@ -244,8 +247,9 @@ void AddJob::doWork()
     }
 }
 
-DeleteJob::DeleteJob(const QList<QVariant>& files, ReadWriteArchiveInterface *interface, QObject *parent)
-        : Job(interface, parent), m_files(files)
+DeleteJob::DeleteJob(const QVariantList& files, ReadWriteArchiveInterface *interface, QObject *parent)
+    : Job(interface, parent)
+    , m_files(files)
 {
 }
 
@@ -254,8 +258,7 @@ void DeleteJob::doWork()
     emit description(this, i18np("Deleting a file from the archive", "Deleting %1 files", m_files.count()));
 
     ReadWriteArchiveInterface *m_writeInterface =
-        qobject_cast<ReadWriteArchiveInterface*>
-        (m_interface);
+        qobject_cast<ReadWriteArchiveInterface*>(m_interface);
 
     Q_ASSERT(m_writeInterface);
 
@@ -266,6 +269,7 @@ void DeleteJob::doWork()
         m_interface->finished(ret);
     }
 }
+
 } // namespace Kerfuffle
 
 #include "jobs.moc"
