@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2008 Harald Hvaal <haraldhv )@@@( stud(dot)ntnu.no>
+ * Copyright (c) 2008 Harald Hvaal <haraldhv@stud.ntnu.no>
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
@@ -26,23 +26,31 @@
 #include "threading.h"
 #include <KDebug>
 
+#include <QTimer>
+
+//#define DEBUG_RACECONDITION
+
 namespace Kerfuffle
 {
 ThreadExecution::ThreadExecution(Kerfuffle::Job *job)
         : m_job(job)
 {
-    connect(m_job, SIGNAL(result(KJob*)), this, SLOT(quit()));
 }
 
 void ThreadExecution::run()
 {
-    kDebug(1601) << "Run";
+    connect(m_job, SIGNAL(result(KJob*)), this, SLOT(quit()), Qt::DirectConnection);
 
-    m_job->doWork();
+    QTimer doWorkTimer;
+    doWorkTimer.setSingleShot(true);
+    connect(&doWorkTimer, SIGNAL(timeout()), m_job, SLOT(doWork()), Qt::DirectConnection);
+    doWorkTimer.start(0);
 
     exec();
 
-    kDebug(1601) << "Finished exec";
+#ifdef DEBUG_RACECONDITION
+    QThread::sleep(2);
+#endif
 }
 }
 
