@@ -34,6 +34,7 @@
 #include <KPushButton>
 #include <KRun>
 #include <KIO/NetAccess>
+#include <khtml_part.h>
 
 #include <QHBoxLayout>
 #include <QFrame>
@@ -47,18 +48,20 @@ ArkViewer::ArkViewer(QWidget * parent, Qt::WFlags flags)
     m_widget->layout()->setSpacing(10);
 
     setMainWidget(m_widget);
+
+    connect(this, SIGNAL(finished()), SLOT(dialogClosed()));
 }
 
 ArkViewer::~ArkViewer()
 {
 }
 
-void ArkViewer::closeEvent(QCloseEvent *event)
+void ArkViewer::dialogClosed()
 {
     if (m_part) {
-        KProgressDialog progressDialog(this,
-                                       i18n("Closing preview"),
-                                       i18n("Please wait while the preview is being closed..."));
+        KProgressDialog progressDialog
+            (this, i18n("Closing preview"),
+             i18n("Please wait while the preview is being closed..."));
 
         progressDialog.setMinimumDuration(500);
         progressDialog.setModal(true);
@@ -67,8 +70,6 @@ void ArkViewer::closeEvent(QCloseEvent *event)
 
         m_part->closeUrl();
     }
-
-    KDialog::closeEvent(event);
 }
 
 void ArkViewer::view(const QString& filename, QWidget *parent)
@@ -114,11 +115,11 @@ void ArkViewer::keyPressEvent(QKeyEvent *event)
 
 bool ArkViewer::viewInInternalViewer(const QString& filename)
 {
-    KUrl u(filename);
+    const KUrl fileUrl(filename);
 
-    KMimeType::Ptr mimetype = KMimeType::findByUrl(u, 0, true);
+    KMimeType::Ptr mimetype = KMimeType::findByUrl(fileUrl, 0, true);
 
-    setCaption(u.fileName());
+    setCaption(fileUrl.fileName());
     // TODO: Load the size from the config file
     QSize size = QSize();
     if (size.width() < 200)
@@ -136,7 +137,7 @@ bool ArkViewer::viewInInternalViewer(const QString& filename)
     KVBox *headerRight = new KVBox(header);
     headerLayout->addWidget(headerRight);
     new QLabel(QString("<qt><b>%1</b></qt>")
-               .arg(KUrl(filename).fileName()), headerRight
+               .arg(fileUrl.fileName()), headerRight
               );
     new QLabel(mimetype->comment(), headerRight);
 
@@ -156,7 +157,20 @@ bool ArkViewer::viewInInternalViewer(const QString& filename)
                 SLOT(slotOpenUrlRequestDelayed(KUrl, KParts::OpenUrlArguments, KParts::BrowserArguments)));
     }
 
-    m_part->openUrl(filename);
+    // #235546
+    // TODO: the user should be warned in a non-intrusive way that some features are going to be disabled
+    //       maybe there should be an option controlling this
+    KHTMLPart *khtmlPart = qobject_cast<KHTMLPart*>(m_part);
+    if (khtmlPart) {
+        kDebug() << "Disabling javascripts, plugins, java and external references for KHTMLPart";
+        khtmlPart->setJScriptEnabled(false);
+        khtmlPart->setJavaEnabled(false);
+        khtmlPart->setPluginsEnabled(false);
+        khtmlPart->setMetaRefreshEnabled(false);
+        khtmlPart->setOnlyLocalReferences(true);
+    }
+
+    m_part->openUrl(fileUrl);
 
     return true;
 }
