@@ -33,7 +33,7 @@
 #include <KComboBox>
 #include <KLocale>
 
-#include "kgpginterface.h"
+#include "kgpgkey.h"
 #include "convert.h"
 #include "images.h"
 #include "kgpgchangekey.h"
@@ -45,12 +45,14 @@
 using namespace KgpgCore;
 
 KgpgTrustLabel::KgpgTrustLabel(QWidget *parent, const QString &text, const QColor &color)
-              : QWidget(parent)
+	: QWidget(parent),
+	m_text_w(new QLabel(this)),
+	m_color_w(new QLabel(this)),
+	m_text(text),
+	m_color(color)
 {
-    m_text_w = new QLabel(this);
     m_text_w->setTextInteractionFlags(Qt::TextSelectableByMouse);
 
-    m_color_w = new QLabel(this);
     m_color_w->setLineWidth(1);
     m_color_w->setFrameShape(QFrame::Box);
     m_color_w->setAutoFillBackground(true);
@@ -61,8 +63,6 @@ KgpgTrustLabel::KgpgTrustLabel(QWidget *parent, const QString &text, const QColo
     layout->addWidget(m_text_w);
     layout->addWidget(m_color_w);
 
-    m_text = text;
-    m_color = color;
     change();
 }
 
@@ -100,34 +100,19 @@ void KgpgTrustLabel::change()
 KgpgKeyInfo::KgpgKeyInfo(KGpgKeyNode *node, KGpgItemModel *model, QWidget *parent)
 	: KDialog(parent),
 	keychange(new KGpgChangeKey(node)),
-	m_key(node->getKey()),
 	m_node(node),
-	m_model(model)
+	m_model(model),
+	m_changepass(NULL),
+	m_keywaschanged(false)
 {
-	init();
-}
+	Q_ASSERT(m_model != NULL);
+	Q_ASSERT(m_node != NULL);
 
-KgpgKeyInfo::KgpgKeyInfo(KgpgCore::KgpgKey *key, QWidget *parent)
-	: KDialog(parent),
-	keychange(new KGpgChangeKey(key)),
-	m_key(key),
-	m_node(NULL),
-	m_model(NULL)
-{
-	init();
-}
-
-void KgpgKeyInfo::init()
-{
     setButtons(Ok | Apply | Cancel);
     setDefaultButton(Ok);
     setModal(true);
     enableButtonApply(false);
 
-    m_keywaschanged = false;
-
-    m_changepass = NULL;
-
     QWidget *page = new QWidget(this);
     QWidget *top = new QWidget(page);
     QWidget *right = new QWidget(top);
@@ -166,19 +151,12 @@ void KgpgKeyInfo::init()
     connect(keychange, SIGNAL(done(int)), SLOT(slotApplied(int)));
 
     displayKey();
-    if (!m_hasphoto)
-        m_photoid->setEnabled(false);
-    else
-        slotLoadPhoto(m_photoid->currentText());
 }
 
 KgpgKeyInfo::~KgpgKeyInfo()
 {
 	if (keychange)
 		keychange->selfdestruct(false);
-	if (!m_node)
-		delete m_key;
-	delete m_changepass;
 }
 
 QGroupBox* KgpgKeyInfo::_keypropertiesGroup(QWidget *parent)
@@ -297,16 +275,13 @@ QGroupBox* KgpgKeyInfo::_buttonsGroup(QWidget *parent)
     QGroupBox *group = new QGroupBox(parent);
     m_disable = new QCheckBox(i18n("Disable key"), group);
 
-    if (m_key->secret())
-    {
+    if (m_node->isSecret()) {
         m_expirationbtn = new KPushButton(i18n("Change Expiration..."), group);
         m_password = new KPushButton(i18n("Change Passphrase..."), group);
 
         connect(m_expirationbtn, SIGNAL(clicked()), this, SLOT(slotChangeDate()));
         connect(m_password, SIGNAL(clicked()), this, SLOT(slotChangePass()));
-    }
-    else
-    {
+    } else {
         m_password = 0;
         m_expirationbtn = 0;
     }
@@ -318,8 +293,7 @@ QGroupBox* KgpgKeyInfo::_buttonsGroup(QWidget *parent)
     layout->setSpacing(spacingHint());
     layout->addWidget(m_disable);
 
-    if (m_key->secret())
-    {
+    if (m_node->isSecret()) {
         layout->addWidget(m_expirationbtn);
         layout->addWidget(m_password);
     }
@@ -341,33 +315,15 @@ QGroupBox* KgpgKeyInfo::_fingerprintGroup(QWidget *parent)
     return group;
 }
 
-void KgpgKeyInfo::reloadKey()
-{
-	KgpgInterface *interface = new KgpgInterface();
-	KgpgKeyList listkeys = interface->readPublicKeys(true, m_key->fullId());
-	delete interface;
-
-	Q_ASSERT(listkeys.count() > 0);
-
-	delete m_key;
-	m_key = new KgpgKey(listkeys.at(0));
-	displayKey();
-}
-
 void KgpgKeyInfo::reloadNode()
 {
-	Q_ASSERT(m_model != NULL);
-	Q_ASSERT(m_node != NULL);
-
 	const QString kid(m_node->getId());
 
 	// this will delete m_node
-	m_key = NULL;
 	m_model->refreshKey(m_node);
 
 	m_node = m_model->getRootNode()->findKey(kid);
 	if (m_node != NULL) {
-		m_key = m_node->getKey();
 		displayKey();
 	} else {
 		KMessageBox::error(this, i18n("<qt>The requested key is not present in the keyring anymore.<br />Perhaps it was deleted by another application</qt>"), i18n("Key not found"));
@@ -378,56 +334,46 @@ void KgpgKeyInfo::reloadNode()
 
 void KgpgKeyInfo::displayKey()
 {
-    QString name = m_key->name();
+    const QString name = m_node->getName();
     setCaption(name);
     m_name->setText("<qt><b>" + name + "</b></qt>");
 
-    if (m_key->email().isEmpty())
-    {
+    const QString email = m_node->getEmail();
+    if (email.isEmpty()) {
         m_email->setText(i18nc("no email address", "none"));
-        m_email->setUrl("");
-    }
-    else
-    {
-        m_email->setText("<qt><b>&lt;" + m_key->email() + "&gt;</b></qt>");
-        m_email->setUrl("mailto:" + name + '<' + m_key->email() + '>');
+        m_email->setUrl(QString());
+    } else {
+        m_email->setText("<qt><b>&lt;" + email + "&gt;</b></qt>");
+        m_email->setUrl("mailto:" + name + '<' + email + '>');
     }
 
-    KgpgKeyTrust keytrust = m_key->valid() ? m_key->trust() : TRUST_DISABLED;
+    const KgpgKey *key = m_node->getKey();
+
+    KgpgKeyTrust keytrust = key->valid() ? m_node->getTrust() : TRUST_DISABLED;
     QString tr = Convert::toString(keytrust);
     QColor trustcolor = Convert::toColor(keytrust);
 
-    m_id->setText(m_key->fullId());
-    m_algorithm->setText(Convert::toString(m_key->algorithm()) + " / " + Convert::toString(m_key->encryptionAlgorithm()));
+    m_id->setText(m_node->getId().right(16));
+    m_algorithm->setText(Convert::toString(key->algorithm()) + " / " + Convert::toString(key->encryptionAlgorithm()));
     m_algorithm->setWhatsThis(i18n("<qt>The left part is the algorithm used by the <b>signature</b> key. The right part is the algorithm used by the <b>encryption</b> key.</qt>"));
-    m_creation->setText(m_key->creation());
-    m_expiration->setText(m_key->expiration());
+    m_creation->setText(Convert::toString(m_node->getCreation().date()));
+    if (m_node->getExpiration().isNull())
+        m_expiration->setText(i18nc("Unlimited key lifetime", "Unlimited"));
+    else
+        m_expiration->setText(Convert::toString(m_node->getExpiration().date()));
     m_trust->setText(tr);
     m_trust->setColor(trustcolor);
-    m_length->setText(QString::number(m_key->size()) + " / " + QString::number(m_key->encryptionSize()));
+    m_length->setText(m_node->getSize());
     m_length->setWhatsThis(i18n("<qt>The left part is the size of the <b>signature</b> key. The right part is the size of the <b>encryption</b> key.</qt>"));
-    m_fingerprint->setText(m_key->fingerprintBeautified());
+    m_fingerprint->setText(m_node->getBeautifiedFingerprint());
 
-    if (m_key->comment().isEmpty())
+    const QString comment = m_node->getComment();
+    if (comment.isEmpty())
         m_comment->setText(i18nc("no key comment", "none"));
     else
-        m_comment->setText(m_key->comment());
+        m_comment->setText(comment);
 
-    QStringList photolist = m_key->photoList();
-    m_photoid->clear();
-    if (photolist.isEmpty())
-    {
-        m_photoid->setVisible(false);
-        m_hasphoto = false;
-    }
-    else
-    {
-        m_photoid->setVisible(true);
-        m_hasphoto = true;
-        m_photoid->addItems(photolist);
-    }
-
-    switch (m_key->ownerTrust())
+    switch (key->ownerTrust())
     {
         case OWTRUST_NONE:
             m_owtrust->setCurrentIndex(1);
@@ -451,8 +397,12 @@ void KgpgKeyInfo::displayKey()
             break;
     }
 
-    if (!m_key->valid())
+    if (!key->valid())
         m_disable->setChecked(true);
+
+    connect(m_node, SIGNAL(expanded()), SLOT(slotKeyExpanded()));
+    m_node->expand();
+    m_photoid->clear();
 }
 
 void KgpgKeyInfo::slotOpenUrl(const QString &url) const
@@ -462,18 +412,11 @@ void KgpgKeyInfo::slotOpenUrl(const QString &url) const
 
 void KgpgKeyInfo::slotLoadPhoto(const QString &uid)
 {
-    KgpgInterface *interface = new KgpgInterface();
-    connect(interface, SIGNAL(loadPhotoFinished(QPixmap, KgpgInterface*)), this, SLOT(slotSetPhoto(QPixmap, KgpgInterface*)));
-    interface->loadPhoto(m_key->fullId(), uid);
-}
-
-void KgpgKeyInfo::slotSetPhoto(const QPixmap &pixmap, KgpgInterface *interface)
-{
-    interface->deleteLater();
-
-    QImage img = pixmap.toImage();
-    QPixmap pix = QPixmap::fromImage(img.scaled(m_photo->width(), m_photo->height(), Qt::KeepAspectRatio));
-    m_photo->setPixmap(pix);
+	int i = uid.toInt();
+	QPixmap pixmap = m_node->getUid(i)->toUatNode()->getPixmap();
+	QImage img = pixmap.toImage();
+	pixmap = QPixmap::fromImage(img.scaled(m_photo->width(), m_photo->height(), Qt::KeepAspectRatio));
+	m_photo->setPixmap(pixmap);
 }
 
 void KgpgKeyInfo::slotPreOk()
@@ -487,7 +430,7 @@ void KgpgKeyInfo::slotPreOk()
 
 void KgpgKeyInfo::slotChangeDate()
 {
-	QPointer<SelectExpiryDate> dialog = new SelectExpiryDate(this, m_key->expirationDate());
+	QPointer<SelectExpiryDate> dialog = new SelectExpiryDate(this, m_node->getExpiration());
 	if (dialog->exec() == QDialog::Accepted) {
 		keychange->setExpiration(dialog->date());
 		enableButtonApply(keychange->wasChanged());
@@ -504,7 +447,7 @@ void KgpgKeyInfo::slotDisableKey(const bool &ison)
 void KgpgKeyInfo::slotChangePass()
 {
 	if (m_changepass == NULL) {
-		m_changepass = new KGpgChangePass(this, m_key->fingerprint());
+		m_changepass = new KGpgChangePass(this, m_node->getId());
 
 		connect(m_changepass, SIGNAL(done(int)), SLOT(slotInfoPasswordChanged(int)));
 	}
@@ -566,10 +509,7 @@ void KgpgKeyInfo::slotApplied(int result)
 		KMessageBox::error(this, i18n("Changing key properties failed."), i18n("Key properties"));
 	} else {
 		m_keywaschanged = true;
-		if (m_node != NULL)
-			reloadNode();
-		else
-			reloadKey();
+		reloadNode();
 	}
 	setControlEnable(true);
 }
@@ -581,4 +521,25 @@ void KgpgKeyInfo::slotPreCancel()
 	reject();
 }
 
+void KgpgKeyInfo::slotKeyExpanded()
+{
+	// the counting starts at 1 and that is the primary uid which can't be a photo id
+	int i = 2;
+	const KGpgSignableNode *uat;
+
+	while ((uat = m_node->getUid(i++)) != NULL) {
+		if (uat->getType() != KgpgCore::ITYPE_UAT)
+			continue;
+
+		m_photoid->addItem(uat->getId());
+	}
+
+	bool hasphoto = (m_photoid->count() > 0);
+
+	m_photoid->setVisible(hasphoto);
+	m_photoid->setEnabled(hasphoto);
+	if (hasphoto)
+		slotLoadPhoto(m_photoid->currentText());
+}
+
 #include "keyinfodialog.moc"
