@@ -28,7 +28,6 @@
 #include <KDateTime>
 
 #include "keylistproxymodel.h"
-#include "kgpginterface.h"
 #include "kgpgitemmodel.h"
 #include "kgpgsearchresultmodel.h"
 #include "kgpgsettings.h"
@@ -36,6 +35,7 @@
 #include "convert.h"
 #include "gpgproc.h"
 #include "kgpgkeyservergettransaction.h"
+#include "kgpgkeyserversearchtransaction.h"
 #include "kgpgsendkeys.h"
 #include "kgpgimport.h"
 
@@ -108,9 +108,25 @@ void KeyServer::slotImport()
 		return;
 	}
 
+	startImport(page->kLEimportid->text().simplified().split(' '), page->kCBimportks->currentText(), page->kLEproxyI->text());
+}
+
+void KeyServer::startImport(const QStringList &keys, QString server, const QString &proxy)
+{
+	if (server.isEmpty()) {
+		const QStringList kservers = KeyServer::getServerList();
+		if (kservers.isEmpty()) {
+			KMessageBox::sorry(this, i18n("You need to configure keyservers before trying to download keys."),
+					i18n("No keyservers defined"));
+			return;
+		}
+
+		server = kservers.first();
+	}
+
 	QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
 
-	KGpgReceiveKeys *proc = new KGpgReceiveKeys(this, page->kCBimportks->currentText(), page->kLEimportid->text().simplified().split(' '), true, page->kLEproxyI->text());
+	KGpgReceiveKeys *proc = new KGpgReceiveKeys(this, server, keys, true, proxy);
 	connect(proc, SIGNAL(done(int)), SLOT(slotDownloadKeysFinished(int)));
 
 	proc->start();
@@ -125,8 +141,10 @@ void KeyServer::slotDownloadKeysFinished(int resultcode)
 
 	t->deleteLater();
 
-	if (resultcode == KGpgTransaction::TS_USER_ABORTED)
+	if (resultcode == KGpgTransaction::TS_USER_ABORTED) {
+		emit importFailed();
 		return;
+	}
 
 	const QStringList keys(KGpgImport::getImportedIds(log));
 	const QString resultmessage(KGpgImport::getImportMessage(log));
@@ -135,7 +153,8 @@ void KeyServer::slotDownloadKeysFinished(int resultcode)
 		emit importFinished(keys);
 
 	(void) new KgpgDetailedInfo(this, resultmessage, log.join(QString('\n')),
-			KGpgImport::getDetailedImportMessage(log).split('\n'));
+			KGpgImport::getDetailedImportMessage(log).split('\n'),
+			i18nc("Caption of message box", "Key Import Finished"));
 }
 
 void KeyServer::slotExport(const QStringList &keyIds)
@@ -207,7 +226,6 @@ void KeyServer::slotSearch()
 	connect(m_dialogserver, SIGNAL(okClicked()), this, SLOT(slotPreImport()));
 	connect(m_listpop->kLVsearch, SIGNAL(activated(const QModelIndex &)), m_dialogserver, SIGNAL(okClicked()));
 	connect(m_dialogserver, SIGNAL(closeClicked()), this, SLOT(handleQuit()));
-	connect(m_listpop, SIGNAL(destroyed()), this, SLOT(slotAbortSearch()));
 	connect(m_listpop->kLEID, SIGNAL(clearButtonClicked()), m_listpop->kLVsearch->selectionModel(), SLOT(clearSelection()));
 
 	m_listpop->kLVsearch->setSelectionMode(QAbstractItemView::ExtendedSelection);
@@ -218,21 +236,14 @@ void KeyServer::slotSearch()
 	const QString keyserv(page->kCBimportks->currentText());
 
 	bool useproxy = page->cBproxyI->isChecked();
-	const QString proxy(page->kLEproxyI->text());
+	QString proxy;
+	if (useproxy)
+		proxy = page->kLEproxyI->text();
 
-	m_searchproc = new GPGProc(this);
-
-	if (useproxy) {
-		m_searchproc->setEnvironment(QStringList("http_proxy=" + proxy));
-		*m_searchproc << "--keyserver-options" << "honor-http-proxy";
-	} else {
-		*m_searchproc << "--keyserver-options" << "no-honor-http-proxy";
-	}
-	*m_searchproc << "--keyserver" << keyserv << "--status-fd=1" << "--command-fd=0";
-	*m_searchproc << "--with-colons"<< "--search-keys"  << page->kLEimportid->text().simplified();
-
-	connect(m_searchproc, SIGNAL(processExited(GPGProc *)), this, SLOT(slotSearchResult(GPGProc *)));
-	connect(m_searchproc, SIGNAL(readReady(GPGProc *)), this, SLOT(slotSearchRead(GPGProc *)));
+	m_searchproc = new KGpgKeyserverSearchTransaction(this, keyserv, page->kLEimportid->text().simplified(),
+			true, proxy);
+	connect(m_searchproc, SIGNAL(done(int)), SLOT(slotSearchResult(int)));
+	connect(m_searchproc, SIGNAL(newKey(QStringList)), m_resultmodel, SLOT(slotAddKey(QStringList)));
 	m_searchproc->start();
 
 	QApplication::setOverrideCursor(QCursor(Qt::BusyCursor));
@@ -241,60 +252,31 @@ void KeyServer::slotSearch()
 	m_dialogserver->exec();
 }
 
-void KeyServer::slotAbortSearch()
-{
-	if (m_searchproc != NULL) {
-		if (m_searchproc->state() == QProcess::Running) {
-			QApplication::restoreOverrideCursor();
-			disconnect(m_searchproc, 0, 0, 0);
-			m_searchproc->kill();
-		}
-		m_searchproc->deleteLater();
-		m_searchproc = NULL;
-	}
-	page->Buttonsearch->setEnabled(true);
-
-	if (m_dialogserver) {
-		delete m_dialogserver;
-		m_dialogserver = NULL;
-	}
-}
-
-void KeyServer::slotSearchRead(GPGProc *p)
-{
-	QString line;
-
-	while (p->readln(line, true) >= 0) {
-		if (line.startsWith(QLatin1String("[GNUPG:] GET_LINE keysearch.prompt"))) {
-			if (m_count < 4)
-				p->write("N\n");
-			else
-				p->write("Q\n");
-		} else if (line.startsWith(QLatin1String("[GNUPG:] GOT_IT"))) {
-			m_count++;
-			line.clear();
-		} else if (!line.isEmpty() && !line.startsWith(QLatin1String("[GNUPG:] "))) {
-			m_resultmodel->addResultLine(line);
-		}
-	}
-}
-
-void KeyServer::slotSearchResult(GPGProc *)
+void KeyServer::slotSearchResult(int result)
 {
+	Q_ASSERT(sender() == m_searchproc);
 	m_searchproc->deleteLater();
 	m_searchproc = NULL;
 	page->Buttonsearch->setEnabled(true);
-
-	m_resultmodel->addResultLine(QString());
-
-	m_dialogserver->enableButtonOk(true);
 	QApplication::restoreOverrideCursor();
 
-	int keys = m_resultmodel->rowCount(QModelIndex());
-	m_listpop->statusText->setText(i18np("Found 1 matching key", "Found %1 matching keys", keys));
+	if (result == KGpgTransaction::TS_USER_ABORTED) {
+		delete m_dialogserver;
+		m_dialogserver = NULL;
+		return;
+	}
 
-	if (keys > 0)
-		m_listpop->kLVsearch->selectionModel()->setCurrentIndex(m_resultmodel->index(0,0), QItemSelectionModel::SelectCurrent | QItemSelectionModel::Rows);
+	m_dialogserver->enableButtonOk(true);
+
+	const int keys = m_resultmodel->rowCount(QModelIndex());
+
+	if (keys > 0) {
+		m_listpop->statusText->setText(i18np("Found 1 matching key", "Found %1 matching keys", keys));
+		m_listpop->kLVsearch->selectionModel()->setCurrentIndex(m_resultmodel->index(0, 0),
+				QItemSelectionModel::SelectCurrent | QItemSelectionModel::Rows);
+	} else {
+		m_listpop->statusText->setText(i18n("No matching keys found"));
+	}
 }
 
 void KeyServer::slotSetText(const QString &text)
@@ -375,12 +357,9 @@ QStringList KeyServer::getServerList()
 void KeyServer::handleQuit()
 {
 	if (m_searchproc != NULL) {
-		if (m_searchproc->state() == QProcess::Running) {
-			QApplication::restoreOverrideCursor();
-			disconnect(m_searchproc, 0, 0, 0);
-			m_searchproc->kill();
-		}
-		delete m_searchproc;
+		QApplication::restoreOverrideCursor();
+		disconnect(m_searchproc, 0, 0, 0);
+		m_searchproc->deleteLater();
 		m_searchproc = NULL;
 	}
 	m_dialogserver->close();
