@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2008,2009 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
@@ -16,14 +16,15 @@
 
 #include <QObject>
 
-#include "kgpgtransaction.h"
+#include "kgpgeditkeytransaction.h"
 
 /**
- * \brief enable of disable a key
+ * @brief enable of disable a key
  */
-class KGpgChangeDisable: public KGpgTransaction {
+class KGpgChangeDisable: public KGpgEditKeyTransaction {
 	Q_OBJECT
 
+	Q_DISABLE_COPY(KGpgChangeDisable)
 public:
 	KGpgChangeDisable(QObject *parent, const QString &keyid, const bool &disable);
 	virtual ~KGpgChangeDisable();
@@ -31,11 +32,8 @@ public:
 	void setDisable(const bool &disable);
 
 protected:
+	virtual bool preStart();
 	virtual bool nextLine(const QString &line);
-
-private:
-	bool m_disable;
-	int m_disablepos;
 };
 
 #endif // KGPGCHANGEDISABLE_H
