@@ -25,7 +25,7 @@
 
 int main(int argc, char *argv[])
 {
-   KAboutData aboutData("sweeper", 0, ki18n("Sweeper"), "1.3",
+   KAboutData aboutData("sweeper", 0, ki18n("Sweeper"), "1.5",
                         ki18n("Helps clean unwanted traces the user leaves on the system."),
                         KAboutData::License_LGPL, ki18n("(c) 2003-2005, Ralf Hoelzer"), KLocalizedString(),
                         "http://utils.kde.org/projects/sweeper");
@@ -38,10 +38,20 @@ int main(int argc, char *argv[])
 
    // command line
    KCmdLineArgs::init(argc, argv, &aboutData);
-   KApplication a(true);
-   Sweeper *app = new Sweeper();
+   KCmdLineOptions options;
+   options.add("automatic", ki18n("Sweeps without user interaction"));
+   KCmdLineArgs::addCmdLineOptions(options);
+   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
-   app->show();
+   // Application 
+   KApplication a(true);
+   Sweeper *app;
+   if(args->isSet("automatic")) {
+      app = new Sweeper(true);
+   } else {
+      app = new Sweeper(false);
+      app->show();
+   }   
    return a.exec();
 }
 
